@@ -1,7 +1,7 @@
 package Bencher::Scenario::CompleteUtil::complete_array_elem;
 
-our $DATE = '2016-10-14'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2017-01-25'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 use 5.010001;
 use strict;
@@ -10,7 +10,7 @@ use warnings;
 our $scenario = {
     summary => 'Benchmark complete_array_elem()',
     modules => {
-        'Complete::Util' => {version=>0.45},
+        'Complete::Util' => {version=>0.57},
         'Text::Levenshtein::XS' => {version=>0},
         'Text::Levenshtein::Flexible' => {version=>0},
     },
@@ -234,7 +234,7 @@ Bencher::Scenario::CompleteUtil::complete_array_elem - Benchmark complete_array_
 
 =head1 VERSION
 
-This document describes version 0.04 of Bencher::Scenario::CompleteUtil::complete_array_elem (from Perl distribution Bencher-Scenarios-CompleteUtil), released on 2016-10-14.
+This document describes version 0.05 of Bencher::Scenario::CompleteUtil::complete_array_elem (from Perl distribution Bencher-Scenarios-CompleteUtil), released on 2017-01-25.
 
 =head1 SYNOPSIS
 
@@ -252,7 +252,7 @@ Packaging a benchmark script as a Bencher scenario makes it convenient to includ
 
 Version numbers shown below are the versions used when running the sample benchmark.
 
-L<Complete::Util> 0.51
+L<Complete::Util> 0.58
 
 L<Text::Levenshtein::Flexible> 0.09
 
@@ -298,7 +298,7 @@ L<Text::Levenshtein::XS> 0.503
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) M-5Y71 CPU @ 1.20GHz (2 cores) >>, OS: I<< GNU/Linux LinuxMint version 17.3 >>, OS kernel: I<< Linux version 3.19.0-32-generic >>.
 
 Benchmark with default options (C<< bencher -m CompleteUtil::complete_array_elem >>):
 
@@ -306,16 +306,19 @@ Benchmark with default options (C<< bencher -m CompleteUtil::complete_array_elem
  +------------------+-----------+-----------+------------+-----------+---------+
  | participant      | rate (/s) | time (ms) | vs_slowest |  errors   | samples |
  +------------------+-----------+-----------+------------+-----------+---------+
- | fuzzy-pp-1000    |       3.8 |   260     |        1   |   0.00058 |      20 |
- | fuzzy-pp-100     |      29   |    35     |        7.5 | 6.2e-05   |      21 |
- | fuzzy-xs-1000    |      69   |    15     |       18   | 5.7e-05   |      20 |
- | fuzzy-flex-1000  |     330   |     3     |       87   | 4.3e-06   |      22 |
- | wordmode-1000    |     530   |     1.9   |      140   | 2.4e-06   |      21 |
- | charmode-1000    |     900   |     1.1   |      240   | 6.5e-06   |      20 |
- | prefix-1000      |    1780   |     0.563 |      468   | 2.1e-07   |      20 |
- | prefix-noci-1000 |    2300   |     0.44  |      600   | 1.1e-06   |      20 |
+ | fuzzy-pp-1000    |       4.5 |   220     |        1   |   0.00049 |      20 |
+ | fuzzy-pp-100     |      33   |    30     |        7.5 |   0.00022 |      20 |
+ | fuzzy-xs-1000    |      90   |    10     |       20   |   0.00012 |      21 |
+ | fuzzy-flex-1000  |     470   |     2.1   |      110   | 3.4e-06   |      20 |
+ | wordmode-1000    |     606   |     1.65  |      135   | 9.1e-07   |      20 |
+ | charmode-1000    |    1000   |     1     |      200   | 1.9e-05   |      27 |
+ | prefix-1000      |    2080   |     0.481 |      465   | 5.3e-08   |      20 |
+ | prefix-noci-1000 |    2680   |     0.373 |      600   |   2e-07   |      22 |
  +------------------+-----------+-----------+------------+-----------+---------+
 
+
+To display as an interactive HTML table on a browser, you can add option C<--format html+datatables>.
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Bencher-Scenarios-CompleteUtil>.
@@ -338,7 +341,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
